CallingConvention

Enum CallingConvention 

#[repr(C)]
pub enum CallingConvention {
Show 16 variants Unexposed = 200, Cdecl = 1, Fastcall = 3, Pascal = 5, Stdcall = 2, Thiscall = 4, Vectorcall = 12, Swift = 13, PreserveMost = 14, PreserveAll = 15, Aapcs = 6, AapcsVfp = 7, IntelOcl = 9, RegCall = 8, SysV64 = 11, Win64 = 10,
}
Indicates the calling convention specified for a function type.

Variants



Unexposed = 200

The function type uses a calling convention that is not exposed via this interface.



Cdecl = 1

The function type uses the x86 cdecl calling convention.



Fastcall = 3

The function type uses the x86 fastcall calling convention.



Pascal = 5

The function type uses the x86 pascal calling convention.



Stdcall = 2

The function type uses the x86 stdcall calling convention.



Thiscall = 4

The function type uses the x86 thiscall calling convention.



Vectorcall = 12

The function type uses the x86 vectorcall calling convention.

Only produced by libclang 3.6 and later.



Swift = 13

The function type uses the calling convention for the Swift programming language.

Only produced by libclang 3.9 and later.



PreserveMost = 14

The function type uses a calling convention that perserves most registers.

Only produced by libclang 3.9 and later.



PreserveAll = 15

The function type uses a calling convention that preverses nearly all registers.

Only produced by libclang 3.9 and later.



Aapcs = 6

The function type uses the ARM AACPS calling convention.



AapcsVfp = 7

The function type uses the ARM AACPS-VFP calling convention.



IntelOcl = 9

The function type uses the calling convention for Intel OpenCL built-ins.



RegCall = 8

The function type uses a calling convention that passes as many values in registers as possible.

Only produced by libclang 4.0 and later.



SysV64 = 11

The function type uses the x64 C calling convention as specified in the System V ABI.



Win64 = 10

The function type uses the x64 C calling convention as implemented on Windows.