Crate libafl_cc

source ·
Compiler Wrapper from LibAFL

Re-exports

pub use cfg::CfgEdge;
pub use cfg::ControlFlowGraph;
pub use cfg::EntryBasicBlockInfo;
pub use cfg::HasWeight;
pub use clang::ClangWrapper;
pub use clang::LLVMPasses;

Modules

LLVM style control flow graph with information of AFL-style index of the each edges, use together with AFLCoverage pass having –dump-afl-cfg flag enabled.
LLVM compiler Wrapper from LibAFL

Enums

LibAFL CC Error Type

Constants

extension for static libraries
prefix for static libraries

Traits

Wrap a compiler hijacking its arguments